# References

_MQT Bench_ has a strong foundation in peer‑reviewed research.
Many of its built‑in algorithms are based on methods published in scientific journals and conferences.
For an overview of _MQT Bench_ and its features, see {cite:p}`quetschlich2023mqtbench`.
If you want to cite this article, please use the following BibTeX entry:

```bibtex
@article{quetschlich2023mqtbench,
  title        = {{{MQT Bench}}: {Benchmarking Software and Design Automation Tools for Quantum Computing}},
  shorttitle   = {{MQT Bench}},
  author       = {Quetschlich, Nils and Burgholzer, Lukas and Wille, Robert},
  year         = {2023},
  journal      = {{Quantum}},
  volume       = {7},
  pages        = {1062},
  doi          = {10.22331/q-2023-07-20-1062},
  note         = {{{MQT Bench}} is available at \url{https://www.cda.cit.tum.de/mqtbench/}},
  eprint       = {2204.13719},
  eprinttype   = {arxiv}
}
```

_MQT Bench_ is part of the Munich Quantum Toolkit, which is described in {cite:p}`mqt`.
If you want to cite the Munich Quantum Toolkit, please use the following BibTeX entry:

```bibtex
@inproceedings{mqt,
  title        = {The {{MQT}} Handbook: {{A}} Summary of Design Automation Tools and Software for Quantum Computing},
  shorttitle   = {{The MQT Handbook}},
  author       = {Wille, Robert and Berent, Lucas and Forster, Tobias and Kunasaikaran, Jagatheesan and Mato, Kevin and Peham, Tom and Quetschlich, Nils and Rovara, Damian and Sander, Aaron and Schmid, Ludwig and Schoenberger, Daniel and Stade, Yannick and Burgholzer, Lukas},
  year         = 2024,
  booktitle    = {IEEE International Conference on Quantum Software (QSW)},
  doi          = {10.1109/QSW62656.2024.00013},
  eprint       = {2405.17543},
  eprinttype   = {arxiv},
  addendum     = {A live version of this document is available at \url{https://mqt.readthedocs.io}}
}
```

A full list of references is given below.

```{bibliography}

```
